// ******************************************************************************
// * Licensed Materials - Property of IBM
// * 5724-W86, 5724-X63
// *  Copyright IBM Corporation 2008, 2011. All Rights Reserved.
// * US Government Users Restricted Rights- Use, duplication or disclosure
// * restricted by GSA ADP Schedule Contract with IBM Corp.
// ******************************************************************************
// *
// ******************************************************************************

/*
 * Returns a new function that calls beforeFunction before mainFunction
 */
function callBefore(beforeFunction, mainFunction)
{
  var result = function()
    {
       beforeFunction.apply(this, arguments);
       return mainFunction.apply(this, arguments);
    };
  return result;
}

/*
 * Returns a new function that calls afterFunction after mainFunction
 */
function callAfter(mainFunction, afterFunction)
{
  var result = function()
    {
       var mainResult=mainFunction.apply(this, arguments);
       afterFunction.apply(this, arguments);
       return mainResult;
    };
  return result;
}

/*
 * Returns a new function that calls mainFunction in between beforeFunction and afterFunction.
 */
function callAround(beforeFunction, mainFunction, afterFunction) 
{
  var beforeAndMain=callBefore(beforeFunction, mainFunction);
  return callAfter(beforeAndMain, afterFunction);
}

/*
 * Returns a function that will log entry/exit of mainFunction.
 * Great for debugging
 */
function logBeforeAfter(text, mainFunction)
{
  var before=function()
    {
        logMessage("BEFORE", text + argumentsAsString(arguments));
    };
  var after=function()
    {
        logMessage("AFTER", text + argumentsAsString(arguments));
    };
  return callAround(before, mainFunction, after);
}

/*
 * Return a string representation of the arguments collection passed in
 */
function argumentsAsString(collection)
{
     var result = "(";
     var addComma = function(beginWith)
         { 
              addComma = function(start)
                  {
                       return start + ",";
                  };
              return beginWith;
         };
     collection.iterate(function(every)
         {
              result = addComma(result);
              result = result + every;
         });
     return result + ")";
}
