// ******************************************************************************
// * Licensed Materials - Property of IBM
// * 5724-W86, 5724-X63
// *  Copyright IBM Corporation 2008, 2011. All Rights Reserved.
// * US Government Users Restricted Rights- Use, duplication or disclosure
// * restricted by GSA ADP Schedule Contract with IBM Corp.
// ******************************************************************************
// *
// ******************************************************************************

/**
 * When provided the record and operator this will create metrics
 * @param {PV.Operator} operator - an operator defined by the PV.???Operator syntax
 * @param {PV.Record} record - the PV.Record to be processed
 */
function createMetrics(operator,record){
	var se = record.subelement;
	var currentSubelement =  operator.subelementNamed(se.name);
	//Though this is not completely safe, it's the best we can do at the moment
	addMetric.operator=operator;
	if(currentSubelement != undefined ) {
		processClasses(subElementClasses, currentSubelement, record);
	}
}

/**
 * This function should enhance the record add it to add the Record so that will be
 * picked up by the aggregator.
 * @param {PV.Record} record
 * @param {String} formulaPath
 * @param {boolean} ReportZeroRegarless 
 */
function delta(record, formulaPath,ReportZeroRegardless){
        
	if( isValid(record.Value)) {
		logMessage(5, logComponent, "delta", "adding to aggregator " + formulaPath );
		var reportZeros = false;
		if(isValid(ReportZeroRegardless)) 
		{
			if(ReportZeroRegardless)
			{
				reportZeros = true;
			}
		}
			
		var aggregationSettings= new Object;
		aggregationSettings.formulaPath=formulaPath;
		aggregationSettings.reportZeros=reportZeros;
		if( record.aggSettings != undefined) {
			logMessage(5, logComponent, "delta", "WARNING: Unexpected Behavior, multiple metrics created from one record, one will be discarded");	
		}
		record.aggSettings=aggregationSettings;

	} else {
		if(ReportZeroRegardless){
			var aggregationSettings= new Object;
			aggregationSettings.formulaPath=formulaPath;
			aggregationSettings.reportZeros=ReportZeroRegardless;
			if( record.aggSettings != undefined)
			{
				logMessage(5, logComponent, "delta", "WARNING: Unexpected Behavior, multiple metrics created from one record, one will be discarded");	
			}
			record.aggSettings=aggregationSettings;
			//TODO We know the value is bad, and should be zero... should we do this:
			//record.Value=0;
		}
	}
} 

/**
 * This function overloads the addMetric defined in the APModeler.js
 * @param {PV.Subelement} subElement
 * @param {String} name
 * @param {Date} timestamp
 * @param {Number} value
 */
function addMetric(subElement, name, timestamp, value) {
	if(! isValid(this.operator)) {
		this.operator=GLOBAL_ROOT_OPERATOR;
	}
	if( isValid(this.operator)) {
		if( isValid(value) )
		{	
			//logMessage(5, logComponent, "addMetric", "called overloaded addMetric function" );
			logMessage(5, logComponent, "addMetric", "About to set :" + name + "="  + value );
                  addMetricWithOperator(this.operator,subElement,name,timestamp,value);
		}
	} else {
		logMessage(1, logComponent, "addMetric", "Warning: operator not defined at this time.");
	}
}

/**
 * This function overloads the addProperty in APModeler.js
 * @param {PV.Subelement} subElement - the sub-element this applies to
 * @param {String} name - metric name (formulaPath)
 * @param {String} value 
 */
function addProperty(subElement, name, value) {
	if( isValid(value) )
	{
		subElement.addProperty(name,value);
	}
}

/**
 * Adds a metric to the operator when the value is valid and the rest of the argumenst are passed
 * @param {PV.Operator} operator
 * @param {PV.Subelement} subelement
 * @param {String} formulaPath
 * @param {Date} timestamp
 * @param {String} value
 */
function addMetricWithOperator(operator,subelement, formulaPath, timestamp, value) 
{
	if( !isValidNumber(value) )
          return;
	 var metric = operator.FloatMetric();
	 // This is required as the formulaPath is a symbol in 4.4.1.4 (Green)
	 // DC has figured this out and should be fixed in Lulu
     logMessage("addMetricWithOperator", "about to call toString on formulaPath: " + formulaPath);
     if ( formulaPath != undefined ) { 
        metric.name = formulaPath.toString();
        metric.value = value * 1;
	    metric.timestamp = timestamp;
        metric.resource = subelement;
	    logMessage(5, logComponent, "addMetricWith..", "FTW: metic" + metric);
        operator.addMetric(metric);
     }
	
}
