// ******************************************************************************
// * Licensed Materials - Property of IBM
// * 5724-W86, 5724-X63
// *  Copyright IBM Corporation 2008, 2011. All Rights Reserved.
// * US Government Users Restricted Rights- Use, duplication or disclosure
// * restricted by GSA ADP Schedule Contract with IBM Corp.
// ******************************************************************************
// *
// ******************************************************************************

/**
 * 
 * @id operatorDefinition.js
 */

 /**
  * Creates the RootOperator a simple StreamQuery operator with in-band inventory
  *  @return PV.Operator the operator that is inialized as a root operator
  */

function createRootOperator() {
     var root = PV.StreamQuery("MAIN",createAlcatel5529SdcInputSchema(), onProcessAlcatel5529SDCRecord);
     root.initializeForInbandInventory();

     //Trace tuples only when LOG_DEBUG is turned on
     // if (LOG_DEBUG) root.traceTuples=true;
     // if (LOG_DEBUG) root.modelGenerator.traceAll=true;
     // if (LOG_DEBUG) root.dbInserter.traceTuples=true;
     // if (LOG_DEBUG) root.metricWriter.traceTuples=true;

     // if (LOG_DEBUG) root.handler=logBeforeAfter("onProcessAlcatel5529SDCRecord", onProcessAlcatel5529SDCRecord);
     root.aggregator=createAggregator(root);
	 root.linkGroupAggregator = createLinkGroupAggregator(root);
	 addMetric.operator= root;
     return root;
}


/**
 * Handler function for each emitted record makes calls to create inventory, 
 *   metrics, and submit to appropriate aggregators
 * @param {PV.Record} the current record, ,must contain an element,and subelement object
 */
function onProcessAlcatel5529SDCRecord(record) {
	
        logMessage(4, "onProcessAlcatel5529SDCDRecord", "about to create resources..." + record);
	createResourcesIfNeeded(this,record);
        logMessage(4, "onProcessAlcatel5529SDCDRecord", "about to create metrics...");
	createMetrics(this,record);
        logMessage(4, "onProcessAlcatel5529SDCDRecord", "creating metrics...");
	if(record.aggSettings != undefined) {
                logMessage(4, "onProcessAlcatel5529SDCDRecord", "adding to aggregator... ");
		this.aggregator.add(record)
	}
        logMessage(4, "onProcessAlcatel5529SDCDRecord", "checkin if lag related...");
	if(record.isLagRelated) {
                logMessage(4, "onProcessAlcatel5529SDCDRecord", "is lag related...");
		this.linkGroupAggregator.add(record);
	}
	
	// Check if the last record reach for updating all the sub elements in the file for device name and the device IP
	SUBELEMENT_CACHE[record.descriptorName].RECORD_COUNT = SUBELEMENT_CACHE[record.descriptorName].RECORD_COUNT - 1;
	if( SUBELEMENT_CACHE[record.descriptorName].ON_CLOSE && SUBELEMENT_CACHE[record.descriptorName].RECORD_COUNT == 0 ) {
		logMessage(1, logComponent,"Reach last record for SUBELEMENT_CACHE[" + record.descriptorName + "]");
		for(var elemName in SUBELEMENT_CACHE[record.descriptorName].ELEMENTS) {
			var deviceIp 	= SUBELEMENT_CACHE[record.descriptorName].ELEMENTS[elemName].DEVICE_IP;
			var deviceName 	= SUBELEMENT_CACHE[record.descriptorName].ELEMENTS[elemName].DEVICE_NAME;
			for( var subElementName in SUBELEMENT_CACHE[record.descriptorName].ELEMENTS[elemName].SUBELEMENTS ) {
				if(subElementName != "constructor" &&
						subElementName != "toString" &&
						subElementName != "isFunction" &&
						subElementName != "isNumber" &&
						subElementName != "mixIn" &&
						subElementName != "clone") {
					    logMessage(1, logComponent,"Update subelement [" + subElementName + "] => DeviceIP:" + deviceIp + ", DeviceName:" + deviceName );
					    var currentSubelement=this.subelementNamed(subElementName);
					    if(deviceName != ""){
					    	currentSubelement.addProperty("Alcatel5529SDC_DeviceName",deviceName);
					    }else{
					    	currentSubelement.addProperty("Alcatel5529SDC_DeviceName",record.element.name);
					    }
					    	currentSubelement.addProperty("Alcatel5529SDC_DeviceIP",deviceIp);
					    
					    
					}
				
			}
		}
		//Reset the cache (cleaning up the cache once done with the updates)
		delete SUBELEMENT_CACHE[record.descriptorName];
	}
}

/* This call creates an operator that has initalizeFor* called on it 
 * thereby registering the operator graph with the UBA
 */
GLOBAL_ROOT_OPERATOR=createRootOperator();
